@@ -1,76 +1,71 @@
 from nautical.noaa.buoy.buoy_data import BuoyData
 from nautical.error import NauticalError
 from nautical.location.point import Point
+from typing import List
+from warnings import warn
+from copy import copy
 
 
 class Buoy:
 
-    """
-    This class is meant to serve as the combination of past and present NOAA
-    data for a particular buoy location. This will will include:
-
-    present wave data
-    present swell data
-    past data [currently wave data and swell data]
-    """
-
     def __init__(self, station, description: str = None, location=None) -> None:
         """
         :param station: ID of the station
         :param description: snippet of information to describe this station
         :param location: nautical.location.point.Point [optional]
         """
-        self._station = station
+        self.station = station
+        self.description = description
+        self._location: Point = None
+        self._present: BuoyData = None
+        self._past: List[BuoyData] = []
 
-        self._description = description
-
-        self._location = None
-        if location:
+        if location is not None:
             self.location = location
 
-        self._present = None
-        self._past = []
-
-    @property
-    def station(self):
-        """
-        Don't provide the user with public means of altering
-        the station once it is created.
-        """
-        return self._station
-
-    @property
-    def description(self):
-        """
-        Don't provide the user with public means of altering
-        the description once it is created.
-        """
-        return self._description
-
     @property
     def location(self):
+        """Location Property
+        
+        :return: Copy of the location (Point)
         """
-        Location (nuatical.location.point) of the buoy
-        """
-        return self._location
-
+        return copy(self._location)
+    
     @location.setter
     def location(self, l):
-        """
-        Force the user to add a location as a Point object
-
-        :param l: location of this buoy/station
+        """Location setter/validity checker
+        
+        :param l: Location or Point object to be set for the location of this instance
         """
         if isinstance(l, Point):
             self._location = l
 
+    @property
+    def data(self):
+        """Copy of `present` Property. This is an expansion function
+        for use when the `past` was deprecated.
+
+        :return: Copy of the `present` data stored in this instance
+        """
+        return self.present
+
     @property
     def present(self):
-        return self._present
+        """Present Property, the present data stored in this instance. 
+        This is the most recent set of buoy data that was retrieved.
+
+        :return: Copy of the `present` data stored in this instance
+        """
+        return copy(self._present)
+
+    @data.setter
+    def data(self, p):
+        """Data Setter/validity checker. See `present` setter for more information."""
+        self.present = p
 
     @present.setter
     def present(self, p):
-        """
+        """Present Property Setter/validity Checker.
         If this instance of present data is a BuoyData object and the time is
         more recent that the previous present data, then the old present data
         is moved to the past data and the new instance is kept as the present data.
@@ -88,7 +83,12 @@ class Buoy:
 
     @property
     def past(self):
-        return self._past
+        """Past Property.
+
+        :return: all past instances of Buoy Data objects stored in this instance.
+        """
+        warn("%s past is deprecated" % str(self.__class__.__name__), DeprecationWarning, stacklevel=2)
+        return self._past[:]
 
     @past.setter
     def past(self, p):
@@ -98,6 +98,7 @@ class Buoy:
 
         :param p: list or since instance of BuoyData that is used to fill in the past
         """
+        warn("%s past is deprecated" % str(self.__class__.__name__), DeprecationWarning, stacklevel=2)
         if isinstance(p, BuoyData):
             self._update_past(p)
         elif isinstance(p, list):
@@ -123,19 +124,25 @@ class Buoy:
         :return: string representation of this Buoy
         """
         if not self._location:
-            return str(self._station)
+            return str(self.station)
         else:
-            return "{} at {}".format(self._station, str(self._location))
+            return "{} at {}".format(self.station, str(self._location))
 
     def __eq__(self, other):
         """
-        :return: station id is the same
+        The stations are considered equal if their station ID is the same as the
+        station IDs are meant to be unique. The special case is `SHIP`.
+
+        :param other: Buoy object to compare to this instance.
+        :return: True when the two objects are the same
         """
-        return type(self) == type(other) and self._station == other.station
+        return type(self) == type(other) and self.station == other.station
 
     def __ne__(self, other):
         """
-        :return: station ids are not the same
+        See __eq__ for more information.
+
+        :return: The opposite of __eq__ (==)
         """
         return not self.__eq__(other)
 
@@ -146,4 +153,4 @@ class Buoy:
 
         :return: hash of the station combined with the hash of the description.
         """
-        return hash(str(self._station)) * hash(self._description) if self._description else hash(str(self._station))
+        return hash(str(self.station)) * hash(self.description) if self.description else hash(str(self.station))
